@@ -25,11 +25,13 @@ class BenchmarkCF:
             self,
             output_number: int = 1,
             disable_gpu: bool = False,
+            disable_tf2: bool = False,
             show_progress: bool = False,
             initial_idx: int = 0,
             final_idx: int = TOTAL_FACTUAL,):
         self.output_number = output_number
         self.disable_gpu = disable_gpu
+        self.disable_tf2 = disable_tf2
         self.show_progress = show_progress
         self.initial_idx = initial_idx
         self.final_idx = final_idx
@@ -47,6 +49,7 @@ class BenchmarkCF:
             output_number=self.output_number,
             ds_id_test=dataset_idx,
             disable_gpu=self.disable_gpu,
+            disable_tf2=self.disable_tf2,
             show_progress=self.show_progress,
             initial_idx=self.initial_idx,
             final_idx=self.final_idx)
